const _ = require('lodash');

const business_api = {
    port: ':11180',
    prefix: '/business/api/'
};

const interfaces = {
    login: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        name: 'login',
        uri: business_api.port + business_api.prefix + 'login',
        method: 'POST'
    }],
    // 检索
    retrieval: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'retrieval',
        method: 'POST',
    }],
    // 检索标注
    annotation: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'annotation',
        method: 'POST',
    }],
    // 条件查询
    query: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'condition/query',
        method: 'POST',
    }],
    // 报警查询
    hit: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'hit/alert',
        method: 'POST',
    }],
    // 1: 1
    verify: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'face/verify',
        method: 'POST',
    }],
    // 图像
    get_single_image: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'single/image',
        method: 'POST',
    }],
    upload_image: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'repository/picture/synchronized',
        method: 'POST',
    }],
    get_failed_images: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'repository/picture/failed',
        method: 'POST',
    }],
    read_image: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'storage/image',
        method: 'GET',
        encoding: null,
        qs: true
    }],
    mod_image: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'face/update',
        method: 'POST',
    }],
    del_image: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'face/delete',
        method: 'POST',
    }],
    // 人像库
    get_repository: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'repository',
        method: 'GET'
    }],
    add_repository: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'repository',
        method: 'POST'
    }],
    del_repository: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'repository',
        method: 'DELETE',
        qs: true
    }],
    mod_repository: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'repository',
        method: 'PUT'
    }],
    export_repository: [{
        version: ['pgy'],
        uri: business_api.port + business_api.prefix + 'repository/export',
        method: 'POST'
    }],
    download_repository: [{
        version: ['pgy'],
        uri: business_api.port + business_api.prefix + 'repository/download',
        method: 'GET',
        encoding: null,
        qs: true
    }],
    // 摄像头
    get_camera: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'camera',
        method: 'GET'
    }],
    add_camera: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'camera',
        method: 'POST'
    }],
    del_camera: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'camera',
        method: 'DELETE',
        qs: true
    }],
    mod_camera: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'camera',
        method: 'PUT'
    }],
    get_captures: [{
        version: ['mtx.3', 'pgy'],
        uri: business_api.port + business_api.prefix + 'capture/fetch',
        method: 'POST'
    }],
    get_alerts: [{
        version: ['mtx.3', 'pgy'],
        uri: business_api.port + business_api.prefix + 'alert/fetch',
        method: 'POST'
    }],
    // 摄像头区域
    get_camera_region: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'camera/region',
        method: 'GET'
    }],
    add_camera_region: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'camera/region',
        method: 'POST'
    }],
    del_camera_region: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'camera/region',
        method: 'DELETE',
        qs: true
    }],
    mod_camera_region: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'camera/region',
        method: 'PUT'
    }],
    // 布控
    get_surveillance: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'surveillance/task',
        method: 'GET'
    }],
    add_surveillance: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'surveillance/task',
        method: 'POST'
    }],
    del_surveillance: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'surveillance/task',
        method: 'DELETE',
        qs: true
    }],
    mod_surveillance: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'surveillance/task',
        method: 'PUT'
    }],
    // 离线视频
    get_video: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'video',
        method: 'GET'
    }],
    add_video: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'video',
        method: 'POST'
    }],
    del_video: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'video',
        method: 'DELETE',
        qs: true
    }],
    mod_video: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'video',
        method: 'PUT'
    }],
    // n: N
    get_nntask: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'nntask',
        method: 'GET'
    }],
    add_nntask: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'nntask',
        method: 'POST'
    }],
    del_nntask: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'nntask',
        method: 'DELETE',
        qs: true
    }],
    start_nntask: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'nntask',
        method: 'PUT',
        sub_data: {
            operation: 2
        }
    }],
    stop_nntask: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'nntask',
        method: 'PUT',
        sub_data: {
            operation: 0
        }
    }],
    suspend_nntask: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'nntask',
        method: 'PUT',
        sub_data: {
            operation: 1
        }
    }],
    get_nntask_result: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'hit/nntask',
        method: 'POST'
    }],
    // 用户(组)
    get_user_self: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'user/self',
        method: 'GET'
    }],
    get_user_top: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'user/top',
        method: 'GET'
    }],
    get_user_deep: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'user',
        method: 'GET',
        qs: true
    }],
    add_user: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'user',
        method: 'POST'
    }],
    del_user: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'user',
        method: 'DELETE',
        qs: true
    }],
    mod_user: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'user',
        method: 'PUT'
    }],
    // 部门
    add_group: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'group',
        method: 'POST'
    }],
    del_group: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'group',
        method: 'DELETE',
        qs: true
    }],
    mod_group: [{
        version: ['mtx.3', 'mtx.2', 'pgy'],
        uri: business_api.port + business_api.prefix + 'group',
        method: 'PUT'
    }],
    // 集群
    get_cluster_id: [{
        version: ['mtx.3', 'pgy'],
        uri: business_api.port + business_api.prefix + 'self/cluster_id',
        method: 'GET'
    }],
    get_all_cluster_ids: [{
        version: ['mtx.3', 'pgy'],
        uri: business_api.port + business_api.prefix + 'cluster_ids',
        method: 'GET'
    }]
};

const apis = {};

_.forEach(interfaces, (value, key) => {
    apis[key] = {};
    _.each(value, (api) => {
        _.each(api.version, (v) => {
            apis[key][v] = _.omit(api, 'version');
        });
    });
});

module.exports = apis;
