const async = require('async');
const utils = require('./utils');
const config = require('./config');

const pool = {};

const tick = (id) => {
    if (!pool[id]) {
        return ;
    }
    pool[id].last_revoked_timestamp = utils.now();
};

const getSession = (id) => {
    if (!pool[id]) {
        pool[id] = {};
    }
    return new Promise((resolve, reject) => {
        let sessionId;
        try {
            sessionId = pool[id].session_id;

            if (!sessionId && pool[id].refreshing) {
                return async.whilst(() => pool[id].refreshing, (next) => {
                    setTimeout(next, 50);
                }, () => {
                    resolve(pool[id].session_id);
                });
            }

            // session_id valid
            if (utils.now() - pool[id].last_revoked_timestamp < config.refresh_interval) {
                return resolve(sessionId);
            }

            // else
            setRefreshing(id, true);
            return resolve();
        } catch (e) {
            return resolve();
        }
    });
};

const setRefreshing = (id, status) => {
    if (!pool[id]) {
        pool[id] = {};
    }
    pool[id].refreshing = Boolean(status);
};

const setSession = (id, sessionId) => {
    pool[id] = {
        session_id: sessionId,
        refreshing: false,
        last_revoked_timestamp: utils.now()
    };
};

module.exports = {
    tick, getSession, setSession, setRefreshing
};
